<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>QApplication</name>
    <message>
        <source>MX Tweak</source>
        <translation type="obsolete">MX Rifiniture</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="obsolete">Questa applicazione è solo per Xfce </translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>FinestraPrincipale</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software gestione luminosità (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Retroilluminazione Hardware</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="30"/>
        <source>MX-Tweak</source>
        <translation>MX-Rifiniture</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="56"/>
        <source>Display</source>
        <translation>Schermo</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="61"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="52"/>
        <location filename="../defaultlook.cpp" line="67"/>
        <location filename="../defaultlook.cpp" line="586"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <location filename="../defaultlook.cpp" line="610"/>
        <location filename="../defaultlook.cpp" line="621"/>
        <source>MX Tweak</source>
        <translation>MX Rifiniture</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="147"/>
        <source>Xfce Settings</source>
        <translation>Impostazioni di Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizza il pannello&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="48"/>
        <location filename="../defaultlook.ui" line="161"/>
        <source>Panel</source>
        <translation>Pannello</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="68"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configura il comportamento delle finestre e delle scorciatoie&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="82"/>
        <source>Window Manager</source>
        <translation>Gestore Finestre</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="102"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizza il look del tuo desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="116"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1673"/>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1684"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1701"/>
        <source>Quit application</source>
        <translation> Chiudi applicazione</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1704"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1711"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="169"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="189"/>
        <source>Backup current panel configuration</source>
        <translation>Backup della configurazione attuale del pannello</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="196"/>
        <source>Restore backup panel configuration</source>
        <translation>Ripristina la configurazione del pannello dal backup</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="203"/>
        <source>Restore default panel</source>
        <translation>Ripristina il pannello di default </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="216"/>
        <location filename="../defaultlook.ui" line="1416"/>
        <source>Affects 1st panel</source>
        <translation>Agisce sul 1° pannello</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Display panel vertically</source>
        <translation>Posiziona il pannello verticalmente</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <location filename="../defaultlook.ui" line="1329"/>
        <source>Bottom</source>
        <translation>in basso</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="248"/>
        <location filename="../defaultlook.ui" line="1339"/>
        <source>Top</source>
        <translation>in alto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="256"/>
        <source>Display panel horizontally</source>
        <translation>Posiziona il pannello orizzontalmente</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="276"/>
        <location filename="../defaultlook.ui" line="1334"/>
        <source>Left</source>
        <translation>a sinistra</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="281"/>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Right</source>
        <translation>a destra</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="289"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Effetti su tutti i pannelli&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="309"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pulsanti delle finestre&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="324"/>
        <location filename="../defaultlook.ui" line="427"/>
        <location filename="../defaultlook.ui" line="618"/>
        <location filename="../defaultlook.ui" line="748"/>
        <location filename="../defaultlook.ui" line="871"/>
        <location filename="../defaultlook.ui" line="878"/>
        <location filename="../defaultlook.ui" line="971"/>
        <location filename="../defaultlook.ui" line="1287"/>
        <location filename="../defaultlook.ui" line="1365"/>
        <location filename="../defaultlook.ui" line="1600"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="361"/>
        <source>Theme Options</source>
        <translation>Opzioni Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="391"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Sistema certe parti dei siti web nell&apos;usare il Tema scuro </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="394"/>
        <source>Firefox dark theme tweak</source>
        <translation>Ritocca il Tema scuro di Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="401"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Adatta la finestra di gestione di HexChat al tema scuro</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="453"/>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="460"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="467"/>
        <source>Remove User Theme Set</source>
        <translation>Rimuovi il set del tema utente</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="478"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Salva le impostazioni correnti come set di un tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compositor</source>
        <translation>Compositore</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Avvia lo strumento di configurazione compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Compton settings</source>
        <translation>Impostazioni di Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="540"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Impostazioni del Compositore di Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="543"/>
        <source>Xfwm Settings</source>
        <translation>Impostazioni di Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="572"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositore Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="577"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="585"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Modifica compton.conf direttamente in un editor di testo </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Edit compton.conf</source>
        <translation>Modifica compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="645"/>
        <source>Transparency and shadow options</source>
        <translation>Opzioni di trasparenza e ombreggiatura</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="652"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>Modificare la modalità VBank può ridurre i problemi di sfarfallìo del monitor. Guarda &apos;Aiuto&apos; per avere ulteriori informazioni.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="655"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="663"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="668"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="673"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="678"/>
        <source>off</source>
        <translation>off</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="888"/>
        <source>Config Options</source>
        <translation>Opzioni di config.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1423"/>
        <source>Systray Icon Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1434"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1439"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1444"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1449"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1454"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1459"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1478"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Reimposta Lightdm (shermata di login) al tema di default del sistema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="896"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Reimposta le azioni personalizzate del pulsante destro in Thunar ai valori di default del sistema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1501"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Usa il driver intel invece del driver &quot;modesetting&quot; predefinito (sarà necessario riavviare)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1508"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          NOTA: Verrà fatto un back up nella directory home dell&apos;attuale file /etc/X11/xorg.conf.d/20-intel.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1519"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Usa l&apos;opzione tearfree amdgpu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1526"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>NOTA: verrà eseguito il backup di /etc/X11/xorg.conf.d/20-amd.conf nella tua cartella home</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1537"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Usa l&apos;opzione driver tearfree radeon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1544"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>NOTA: verrà eseguito il backup di /etc/X11/xorg.conf.d/20-radeon.conf nella tua cartella home</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>Display</source>
        <translation>Schermo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Hardware Backlight</source>
        <translation>Retroilluminazione Hardware</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="714"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Regolazioni Schermo&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="741"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Scegli lo schermo per le regolazioni con xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>Resolution</source>
        <translation>Risoluzione</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="781"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Il salvataggio è riferito allo schermo&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="784"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software gestione luminosità (xrandr)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="798"/>
        <location filename="../defaultlook.ui" line="812"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="805"/>
        <source>GTK scaling</source>
        <translation>Valore di scala GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="832"/>
        <source>xrandr Scaling</source>
        <translation>Valore di scala xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="985"/>
        <source>Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1022"/>
        <location filename="../defaultlook.ui" line="1053"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <location filename="../defaultlook.ui" line="1058"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1063"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1199"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="993"/>
        <location filename="../defaultlook.ui" line="1376"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1000"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1007"/>
        <source>Reset DefaultDock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1014"/>
        <source>Toggle desktop icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1035"/>
        <source>Reset Fluxbox Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1042"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1084"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1091"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1098"/>
        <location filename="../defaultlook.ui" line="1206"/>
        <location filename="../defaultlook.ui" line="1383"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1182"/>
        <location filename="../defaultlook.ui" line="1280"/>
        <source>Autohide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1189"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>Plasma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1352"/>
        <source>Enable single-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1318"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1470"/>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1567"/>
        <source>&amp;User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1574"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="917"/>
        <source>Show systray (notification area) frame</source>
        <translation>Mostra la systray (area di notifica)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="924"/>
        <location filename="../defaultlook.ui" line="1403"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Mostra le finestre di tutti gli spazi di lavoro nel pannello</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="903"/>
        <source>Enable single-click on desktop</source>
        <translation>Abilita il click-singolo sul desktop</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="938"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Abilita l&apos;ibernazione sul menu di chiusura</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Permetti il montaggio delle periferiche interne agli utenti non-root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1492"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="945"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   nota: per l&apos;ibernazione, la swap deve essere &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="931"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Disabilitare l&apos;accorciamento dei nomi lunghi dei file nel desktop</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="910"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Abilita il click-singolo sul Gestore di File Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1560"/>
        <source>Password for administrative tasks:</source>
        <translation>Password per attività amministrative:</translation>
    </message>
    <message>
        <source>User</source>
        <translation type="vanished">Utente</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="53"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="585"/>
        <source>About MX Tweak</source>
        <translation>Informazioni su MX Rifiniture</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="586"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="587"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Applicazione per ritocchi e rapide modifiche ai temi predefiniti dell&apos;interfaccia </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="589"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="590"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="591"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="622"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Finito! Potrebbe essere necessario riavviare Firefox perchè le modifiche abbiano effetto</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="vanished">Questa applicazione è solo per Xfce </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="806"/>
        <source>Panel settings</source>
        <translation>Impostazioni Pannello </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="807"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>È stato eseguito il backup delle tue impostazioni correnti del pannello in una cartella nascosta denominata .restore nella tua cartella home (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1408"/>
        <source>settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1745"/>
        <source>Choose a theme set</source>
        <translation>Scegli un set di temi</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Rimuovi il set del tema utente</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nuovo set di tema</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Inserisci il nome per il nuovo set di tema</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Pulsanti delle finestre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aspetto&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Mostra le etichette dei pulsanti</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Usa pulsanti piatti</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Mostra maniglie</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Ordinamento:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Timestamp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Titolo del gruppo e timestamp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Titolo della finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Titolo del gruppo e della finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Nessuno, permetti drag&amp;drop</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Comportamento&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Raggruppa finestre:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Azione del tasto centrale:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Non fare niente</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Chiude la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimizza la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Ripristina le finestre minimizzate nello spazio di lavoro corrente</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Disegna la cornice della finestra quando il puntatore è sul suo pulsante</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Scorri tra le finestre usando la rotella del mouse</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtraggio&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Mostra le finestre di tutti gli spazi di lavoro o porzioni</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Mostra solo le finestre minimizzate</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Mostra le finestre di tutti gli schermi</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Finestre a comparsa</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Finestre durante lo spostamento</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Impostazioni Opacità&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Decorazioni della finestra</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre della barra dock</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre a comparsa</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Finestre durante il ridimensionamento</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre normali</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Impostazione delle funzioni&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Mostra l&apos;anteprima delle finestre al posto delle icone al passaggio</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Visualizza direttamente a pieno schermo le finestre sovrapposte</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Finestre inattive</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronizza il disegno allo spazio vuoto verticale</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Impostazioni del Compositore Xfwm </translation>
    </message>
</context>
</TS>
